@@ -14,9 +14,4 @@
 #ifndef _OSI_PROTO_H_
 #define _OSI_PROTO_H_
 
-/* osi_file.c */
-extern afs_rwlock_t afs_xosi;
-
-
-
 #endif /* _OSI_PROTO_H_ */
