@@ -21,10 +21,6 @@
 #include <linux/unistd.h>		/* For syscall numbers. */
 #include <linux/mm.h>
 
-#ifdef AFS_AMD64_LINUX_ENV
-#include <asm/ia32_unistd.h>
-#endif
-
 #include <linux/proc_fs.h>
 #include <linux/slab.h>
 #include <linux/init.h>
@@ -64,7 +60,7 @@ afs_init_idmap(void)
 }
 #endif
 
-int __init
+static int __init
 afs_init(void)
 {
     int err;
@@ -114,7 +110,7 @@ afs_init(void)
     return 0;
 }
 
-void __exit
+static void __exit
 afs_cleanup(void)
 {
     afs_shutdown_pagecopy();
