@@ -15,6 +15,14 @@
 
 #include "osi_compat.h"
 
+#if defined(STRUCT_DENTRY_HAS_D_CHILDREN)
+# define afs_for_each_child(child, parent) \
+	 hlist_for_each_entry((child), &(parent)->d_children, d_sib)
+#else
+# define afs_for_each_child(child, parent) \
+	 list_for_each_entry((child), &(parent)->d_subdirs, d_child)
+#endif
+
 static void
 TryEvictDirDentries(struct inode *inode)
 {
@@ -272,3 +280,56 @@ osi_ShouldDeferRemunlink(struct vcache *avc)
     }
     return 0;
 }
+
+/*
+ * Invalidate Linux-specific cached data for the given vcache. This doesn't
+ * handle anything with the OpenAFS disk cache or stat cache, etc; those things
+ * are handled by afs_ResetVCache().
+ *
+ * The Linux-specific stuff we clear here is dcache entries. This means
+ * clearing d_time in all dentry's for the vcache, and all immediate children
+ * (for directories). We don't call d_invalidate() or any similar functions
+ * here; let afs_linux_dentry_revalidate() figure out what to do with the
+ * invalid dentry's whenever they are accessed.
+ *
+ * @pre AFS_GLOCK held
+ */
+void
+osi_ResetVCache(struct vcache *avc)
+{
+    struct dentry *dp;
+    struct inode *ip = AFSTOV(avc);
+#if defined(D_ALIAS_IS_HLIST) && !defined(HLIST_ITERATOR_NO_NODE)
+    struct hlist_node *node;
+#endif
+
+    AFS_GUNLOCK();
+
+    afs_d_alias_lock(ip);
+
+    afs_d_alias_foreach(dp, ip, node) {
+	spin_lock(&dp->d_lock);
+
+	/* Invalidate the dentry for the given vcache. */
+	dp->d_time = 0;
+
+	if (S_ISDIR(ip->i_mode)) {
+	    /*
+	     * If the vcache is a dir, also invalidate all of its children.
+	     * Note that we can lock child->d_lock while dp->d_lock is held,
+	     * because 'dp' is an ancestor of 'child'.
+	     */
+	    struct dentry *child;
+	    afs_for_each_child(child, dp) {
+		spin_lock(&child->d_lock);
+		child->d_time = 0;
+		spin_unlock(&child->d_lock);
+	    }
+	}
+
+	spin_unlock(&dp->d_lock);
+    }
+    afs_d_alias_unlock(ip);
+
+    AFS_GLOCK();
+}
