@@ -30,6 +30,7 @@
 #include "afs/afs_bypasscache.h"
 #include "rx/rx_globals.h"
 #include "afsd/afsd.h"
+#include "afs/opr.h"
 
 #define VFS 1
 #undef	VIRTUE
@@ -46,13 +47,6 @@
 #define	CELLINFOFILE	"CellItems"
 #define MAXIPADDRS 64
 
-#ifndef MIN
-#define MIN(A,B)	((A)<(B)?(A):(B))
-#endif
-#ifndef MAX
-#define MAX(A,B)	((A)>(B)?(A):(B))
-#endif
-
 extern int cacheDiskType;
 
 char afs_LclCellName[64];
@@ -276,7 +270,7 @@ usr_uiomove(char *kbuf, int n, int rw, struct usr_uio *uio)
      */
     ptr = kbuf;
     while (nio > 0 && n > 0) {
-	len = MIN(n, iovp->iov_len);
+	len = opr_min(n, iovp->iov_len);
 	if (rw == UIO_READ) {
 	    memcpy(iovp->iov_base, ptr, len);
 	} else {
