@@ -7,6 +7,13 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+/*-
+ * OSI Directory Name Lookup Cache
+ *
+ * Keep a local cache of lookup results to avoid needing to examine the disk
+ * cache, for frequently accessed names.
+ */
+
 #include <afsconfig.h>
 #include "afs/param.h"
 
@@ -32,7 +39,7 @@ extern struct afs_lock afs_xvcache;
 
 dnlcstats_t dnlcstats;
 
-#define NCSIZE 300
+#define NCSIZE 4096
 #define NHSIZE 256		/* must be power of 2. == NHASHENT in dir package */
 struct nc *ncfreelist = NULL;
 static struct nc nameCache[NCSIZE];
@@ -268,42 +275,14 @@ osi_dnlc_lookup(struct vcache *adp, char *aname, int locktype)
 	    return 0;
 	}
 #else
-	osi_vnhold(tvc, 0);
+	if (osi_vnhold(tvc) != 0) {
+	    dnlcstats.misses++;
+	    osi_dnlc_remove(adp, aname, tvc);
+	    tvc = NULL;
+	}
 #endif
 	ReleaseReadLock(&afs_xvcache);
 
-#ifdef	notdef
-	/*
-	 * XX If LRUme ever is non-zero change the if statement around because
-	 * aix's cc with optimizer on won't necessarily check things in order XX
-	 */
-	if (LRUme && (0 == NBObtainWriteLock(&afs_xdnlc))) {
-	    /* don't block to do this */
-	    /* tnc might have been moved during race condition, */
-	    /* but it's always in a legit hash chain when a lock is granted,
-	     * or else it's on the freelist so prev == NULL,
-	     * so at worst this is redundant */
-	    /* Now that we've got it held, and a lock on the dnlc, we
-	     * should check to be sure that there was no race, and
-	     * bail out if there was. */
-	    if (tnc->prev) {
-		/* special case for only two elements on list - relative ordering
-		 * doesn't change */
-		if (tnc->prev != tnc->next) {
-		    /* remove from old location */
-		    tnc->prev->next = tnc->next;
-		    tnc->next->prev = tnc->prev;
-		    /* insert into new location */
-		    tnc->next = nameHash[skey];
-		    tnc->prev = tnc->next->prev;
-		    tnc->next->prev = tnc;
-		    tnc->prev->next = tnc;
-		}
-		nameHash[skey] = tnc;
-	    }
-	    ReleaseWriteLock(&afs_xdnlc);
-	}
-#endif
     }
 
     return tvc;
