@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 1995-1998 The Apache Group.  All rights reserved.
+ * Copyright (c) 1995-1999 The Apache Group.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -67,6 +67,8 @@ extern "C" {
  * See PORTING for a listing of what they mean
  */
 
+#include "ap_mmn.h"		/* MODULE_MAGIC_NUMBER_ */
+
 /*
  * Support for platform dependent autogenerated defines
  */
@@ -82,6 +84,29 @@ stat() properly */
 #include <sys/types.h>
 #include <sys/stat.h>
 
+/* So that we can use inline on some critical functions, and use
+ * GNUC attributes (such as to get -Wall warnings for printf-like
+ * functions).  Only do this in gcc 2.7 or later ... it may work
+ * on earlier stuff, but why chance it.
+ *
+ * We've since discovered that the gcc shipped with NeXT systems
+ * as "cc" is completely broken.  It claims to be __GNUC__ and so
+ * on, but it doesn't implement half of the things that __GNUC__
+ * means.  In particular it's missing inline and the __attribute__
+ * stuff.  So we hack around it.  PR#1613. -djg
+ */
+#if !defined(__GNUC__) || __GNUC__ < 2 || \
+    (__GNUC__ == 2 && __GNUC_MINOR__ < 7) ||\
+    defined(NEXT)
+#define ap_inline
+#define __attribute__(__x)
+#define ENUM_BITFIELD(e,n,w)  signed int n : w
+#else
+#define ap_inline __inline__
+#define USE_GNU_INLINE
+#define ENUM_BITFIELD(e,n,w)  e n : w
+#endif
+
 #ifdef WIN32
 /* include process.h first so we can override spawn[lv]e* properly */
 #include <process.h>
@@ -90,7 +115,7 @@ stat() properly */
 #include "os.h"
 #endif
 
-#if !defined(QNX) && !defined(MPE) && !defined(WIN32)
+#if !defined(QNX) && !defined(MPE) && !defined(WIN32) && !defined(TPF)
 #include <sys/param.h>
 #endif
 
@@ -161,12 +186,10 @@ stat() properly */
 #define HAVE_MMAP 1
 #define USE_MMAP_SCOREBOARD
 #define USE_MMAP_FILES
-
-/* AFS Websecure tweak to compile on Linux */
-#if ! defined(AIX) && ! defined(HAVE_UNISTD_H)
+/* Transarc hack to get AIX to build */
+#if ! defined(AIX) && ! defined(linux)
     int gethostname(char *name, int namelen);
-#endif				/* ! defined(AIX) && ! defined(HAVE_UNISTD_H) */
-
+#endif				/* ! AIX && ! linux */
 #define HAVE_SYSLOG 1
 #define SYS_SIGLIST _sys_siglist
 
@@ -176,8 +199,10 @@ stat() properly */
  * there's some weird conflict with non-BSD signals */
 #define NO_KILLPG
 #undef NO_SETSID
-#if !defined(USE_FCNTL_SERIALIZED_ACCEPT) && !defined(USE_USLOCK_SERIALIZED_ACCEPT)
-#define USE_SYSVSEM_SERIALIZED_ACCEPT
+#if !defined(USE_FLOCK_SERIALIZED_ACCEPT) && \
+    !defined(USE_USLOCK_SERIALIZED_ACCEPT) && \
+    !defined(USE_SYSVSEM_SERIALIZED_ACCEPT)
+#define USE_FCNTL_SERIALIZED_ACCEPT
 #endif
 #define HAVE_SHMGET 1
 #define USE_SHMGET_SCOREBOARD
@@ -260,6 +285,9 @@ stat() properly */
 #endif
 
 #elif defined(ULTRIX)
+/* we don't want to use sys/resource.h under
+   Ultrix although this header exists. */
+#undef HAVE_SYS_RESOURCE_H
 #define HAVE_GMTOFF 1
 #undef NO_KILLPG
 #undef NO_SETSID
@@ -364,6 +392,42 @@ stat() properly */
 #define NO_USE_SIGACTION
 #define HAVE_SYSLOG 1
 
+#elif defined(RHAPSODY)		/* Mac OS X Server */
+#define HAVE_GMTOFF
+#define HAVE_MMAP
+#define USE_MMAP_FILES
+#define USE_MMAP_SCOREBOARD
+#define MAP_TMPFILE
+#define HAVE_RESOURCE
+#define HAVE_SNPRINTF
+#define JMP_BUF jmp_buf
+#define USE_LONGJMP
+#define USE_FLOCK_SERIALIZED_ACCEPT
+#define SINGLE_LISTEN_UNSERIALIZED_ACCEPT
+/*
+ * If you are using APACI, (you should be on Rhapsody) these
+ * values are set at configure time. These are here as reference;
+ * the apache that is built into Rhapsody is configured with
+ * these values.
+ */
+#if 0
+#define HTTPD_ROOT              "/Local/Library/WebServer"
+#define DOCUMENT_LOCATION       HTTPD_ROOT "/Documents"
+#define DEFAULT_XFERLOG         "Logs/Access"
+#define DEFAULT_ERRORLOG        "Logs/Errors"
+#define DEFAULT_PIDLOG          "Logs/Process"
+#define DEFAULT_SCOREBOARD      "Logs/Status"
+#define DEFAULT_LOCKFILE        "Logs/Lock"
+#define SERVER_CONFIG_FILE      "Configuration/Server"
+#define RESOURCE_CONFIG_FILE    "Configuration/Resources"
+#define TYPES_CONFIG_FILE       "Configuration/MIME"
+#define ACCESS_CONFIG_FILE      "Configuration/Access"
+#define DEFAULT_USER_DIR        "Library/Web Documents"
+#define DEFAULT_USER            "nobody"
+#define DEFAULT_GROUP           "nogroup"
+#define DEFAULT_PATH            "/bin:/usr/bin:/usr/local/bin"
+#endif
+
 #elif defined(LINUX)
 
 #if LINUX > 1
@@ -399,13 +463,14 @@ stat() properly */
 #define HAVE_MMAP 1
 #define USE_MMAP_FILES
 
-/* glibc 2.1 and later finally define rlim_t */
-#if !defined(__GLIBC__) || __GLIBC__ < 2 || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 1)
-    typedef int rlim_t;
-#endif
-
 /* flock is faster ... but hasn't been tested on 1.x systems */
-#define USE_FLOCK_SERIALIZED_ACCEPT
+/* PR#3531 indicates flock() may not be stable, probably depends on
+ * kernel version.  Go back to using fcntl, but provide a way for
+ * folks to tweak their Configuration to get flock.
+ */
+#ifndef USE_FLOCK_SERIALIZED_ACCEPT
+#define USE_FCNTL_SERIALIZED_ACCEPT
+#endif
 
 #define SYS_SIGLIST	_sys_siglist
 
@@ -420,6 +485,11 @@ stat() properly */
 #include <sys/time.h>
 #define HAVE_SYSLOG 1
 
+/* glibc 2.1 and later finally define rlim_t */
+#if !defined(__GLIBC__) || __GLIBC__ < 2 || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 1)
+    typedef int rlim_t;
+#endif
+
 #elif defined(SCO)
 #undef HAVE_GMTOFF
 #undef NO_KILLPG
@@ -428,6 +498,7 @@ stat() properly */
 #define NO_WRITEV
 #include <sys/time.h>
 #define HAVE_SYSLOG 1
+#undef HAVE_SYS_RESOURCE_H
 
 #elif defined(SCO5)
 
@@ -502,13 +573,18 @@ stat() properly */
 #define NEED_INITGROUPS
 #define NEED_HASHBANG_EMUL	/* execve() doesn't start shell scripts by default */
 #undef HAVE_SHMGET
+#undef NEED_STRCASECMP
+#undef NEED_STRNCASECMP
 #undef USE_SHMGET_SCOREBOARD
 #undef bzero
 #endif /*_OSD_POSIX*/
 
 #elif defined(UW)
+#if UW < 700
+#define USE_FCNTL_SERIALIZED_ACCEPT
 #define NO_LINGCLOSE
 #define NO_KILLPG
+#endif
 #undef  NO_SETSID
 #undef NEED_STRDUP
 #define NEED_STRCASECMP
@@ -524,14 +600,18 @@ stat() properly */
 #endif
 #define NET_SIZE_T size_t
 #define HAVE_SYSLOG 1
-#define USE_FCNTL_SERIALIZED_ACCEPT
 
 #elif defined(DGUX)
 #define NO_KILLPG
 #undef  NO_SETSID
 #undef NEED_STRDUP
+#ifdef _IX86_DG
+#undef NEED_STRCASECMP
+#undef NEED_STRNCASECMP
+#else
 #define NEED_STRCASECMP
 #define NEED_STRNCASECMP
+#endif
 /* A lot of SVR4 systems need this */
 #define USE_FCNTL_SERIALIZED_ACCEPT
 #define ap_inet_addr inet_network
@@ -547,11 +627,13 @@ stat() properly */
 #endif
 #ifndef DEFAULT_GROUP
 #define DEFAULT_GROUP "nogroup"
+#endif
 #define HAVE_SHMGET 1
 #define HAVE_MMAP 1
 #define USE_MMAP_SCOREBOARD
 #define USE_MMAP_FILES
-#endif
+#define USE_FLOCK_SERIALIZED_ACCEPT
+#define SINGLE_LISTEN_UNSERIALIZED_ACCEPT
 
 #elif defined(UTS21)
 #undef HAVE_GMTOFF
@@ -574,6 +656,7 @@ stat() properly */
 #define WEXITSTATUS(status)	(int)((status).w_retcode)
 #define WTERMSIG(status)	(int)((status).w_termsig)
 #define strftime(buf,bufsize,fmt,tm)    ascftime(buf,fmt,tm)
+#undef HAVE_SYS_RESOURCE_H	/* exists but does not provide *rlimit funcs */
 #include <sys/types.h>
 #include <sys/time.h>
 
@@ -603,6 +686,7 @@ stat() properly */
     typedef quad_t rlim_t;
 #endif
 #define USE_FLOCK_SERIALIZED_ACCEPT
+#define SINGLE_LISTEN_UNSERIALIZED_ACCEPT
 #define HAVE_SYSLOG 1
 #define SYS_SIGLIST sys_siglist
 
@@ -656,15 +740,13 @@ stat() properly */
 #define USE_MMAP_FILES
 #define HAVE_SYSLOG 1
 
-#elif defined(__EMX__)
+#elif defined(OS2)
 /* Defines required for EMX OS/2 port. */
 #define NO_KILLPG
 #define NEED_STRCASECMP
 #define NEED_STRNCASECMP
 #define NO_SETSID
 #define NO_TIMES
-/* ap_config_auto.h gets this wrong, force sys/select.h to be included */
-#define HAVE_SYS_SELECT_H
 #define CASE_BLIND_FILESYSTEM
 /* Add some drive name support */
 #define chdir _chdir2
@@ -672,6 +754,8 @@ stat() properly */
 #define MAXSOCKETS 4096
 #define USE_OS2_SCOREBOARD
 #define NO_RELIABLE_PIPED_LOGS
+#define USE_OS2SEM_SERIALIZED_ACCEPT
+#define SINGLE_LISTEN_UNSERIALIZED_ACCEPT
 
 #elif defined(__MACHTEN__)
     typedef int rlim_t;
@@ -750,10 +834,45 @@ stat() properly */
 #define NO_KILLPG
 #define NEED_INITGROUPS
 
+#elif defined(_CX_SX)
+#define JMP_BUF sigjmp_buf
+#include <sys/types.h>
+#include <sys/time.h>
+
 #elif defined(WIN32)
 
 /* All windows stuff is now in os/win32/os.h */
 
+#elif defined(TPF)		/* IBM Transaction Processing Facility operating system */
+
+#include <tpfeq.h>
+#include <tpfio.h>
+#include <sysapi.h>
+#include <sysgtime.h>
+#define PRIMECRAS 0x010000
+#define JMP_BUF jmp_buf
+#define NEED_INITGROUPS
+#define NEED_STRCASECMP
+#define NEED_STRDUP
+#define NEED_STRNCASECMP
+#define NO_DBM_REWRITEMAP
+#define NO_GETTIMEOFDAY
+#define NO_KILLPG
+#define NO_LINGCLOSE
+#define NO_MMAP
+#define NO_OTHER_CHILD
+#define NO_RELIABLE_PIPED_LOGS
+#define NO_SETSID
+#define NO_SHMGET
+#define NO_SLACK
+#define NO_TIMES
+#define NO_USE_SIGACTION
+#define NO_WRITEV
+#define USE_LONGJMP
+#define USE_TPF_SELECT
+#undef  offsetof
+#define offsetof(s_type,field) ((size_t)&(((s_type*)0)->field))
+
 #else
 /* Unknown system - Edit these to match */
 #ifdef BSD
@@ -802,25 +921,15 @@ stat() properly */
 #define CORE_EXPORT_NONSTD	API_EXPORT_NONSTD
 #endif
 
-/* So that we can use inline on some critical functions, and use
- * GNUC attributes (such as to get -Wall warnings for printf-like
- * functions).  Only do this in gcc 2.7 or later ... it may work
- * on earlier stuff, but why chance it.
- *
- * We've since discovered that the gcc shipped with NeXT systems
- * as "cc" is completely broken.  It claims to be __GNUC__ and so
- * on, but it doesn't implement half of the things that __GNUC__
- * means.  In particular it's missing inline and the __attribute__
- * stuff.  So we hack around it.  PR#1613. -djg
+/* On Mac OS X Server, symbols that conflict with loaded dylibs
+ * (eg. System framework) need to be declared as private symbols with
+ * __private_extern__.
+ * For other systems, make that a no-op.
  */
-#if !defined(__GNUC__) || __GNUC__ < 2 || __GNUC_MINOR__ < 7 || defined(NEXT)
-#define ap_inline
-#define __attribute__(__x)
-#define ENUM_BITFIELD(e,n,w)  signed int n : w
+#if defined(RHAPSODY)
+#define ap_private_extern __private_extern__
 #else
-#define ap_inline __inline__
-#define USE_GNU_INLINE
-#define ENUM_BITFIELD(e,n,w)  e n : w
+#define ap_private_extern
 #endif
 
 /*
@@ -848,7 +957,7 @@ stat() properly */
 #include <stdlib.h>
 #include <string.h>
 #include "ap_ctype.h"
-#if !defined(MPE) && !defined(WIN32)
+#if !defined(MPE) && !defined(WIN32) && !defined(TPF)
 #include <sys/file.h>
 #endif
 #ifndef WIN32
@@ -856,10 +965,12 @@ stat() properly */
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif				/* HAVE_SYS_SELECT_H */
+#ifndef TPF
 #include <netinet/in.h>
+#endif				/* TPF */
 #include <netdb.h>
 #include <sys/ioctl.h>
-#if !defined(MPE) && !defined(BEOS)
+#if !defined(MPE) && !defined(BEOS) && !defined(TPF)
 #include <arpa/inet.h>		/* for inet_ntoa */
 #endif
 #include <sys/wait.h>
@@ -880,9 +991,12 @@ stat() properly */
 #endif				/* ndef WIN32 */
 
 #include <time.h>		/* for ctime */
+#ifdef WIN32
+#define strftime(s,max,format,tm)  os_strftime(s,max,format,tm)
+#endif
 #include <signal.h>
 #include <errno.h>
-#if !defined(QNX) && !defined(CONVEXOS11) && !defined(NEXT)
+#if !defined(QNX) && !defined(CONVEXOS11) && !defined(NEXT) && !defined(TPF)
 #include <memory.h>
 #endif
 
@@ -906,7 +1020,7 @@ stat() properly */
 #endif
 #endif
 #ifdef USE_MMAP_SCOREBOARD
-#if !defined(__EMX__) && !defined(WIN32)
+#if !defined(OS2) && !defined(WIN32)
 /* This file is not needed for OS/2 */
 #include <sys/mman.h>
 #endif
@@ -986,6 +1100,8 @@ stat() properly */
 #ifdef SELECT_NEEDS_CAST
 #define ap_select(_a, _b, _c, _d, _e)	\
     select((_a), (int *)(_b), (int *)(_c), (int *)(_d), (_e))
+#elif defined(USE_TPF_SELECT)
+#define ap_select   tpf_select
 #else
 #define ap_select	select
 #endif
