@@ -9,37 +9,28 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
 #include <afs/stds.h>
-#include <afs/pthread_glock.h>
-#include <sys/types.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <sys/file.h>
-#include <sys/time.h>
-#include <netinet/in.h>
-#include <netdb.h>
+
+#include <roken.h>
+
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wdeprecated-declarations"
 #endif
-#include <string.h>
-#include <stdio.h>
-#include <des.h>
-#include <des_prototypes.h>
+
+#define HC_DEPRECATED
+#include <hcrypto/des.h>
+#include <hcrypto/rand.h>
+
 #include <rx/rxkad.h>
-#if defined(USE_RXKAD_KEYTAB) && !defined(UKERNEL)
-#include <afs/dirpath.h>
-#define KERBEROS_APPLE_DEPRECATED(x)
-#include <krb5.h>
-#endif
 #include <rx/rx.h>
-#include <errno.h>
-#include <afs/afsutil.h>
+
+#include <afs/pthread_glock.h>
+
 #include "cellconfig.h"
 #include "keys.h"
+#include "ktc.h"
 #include "auth.h"
-#if defined(USE_RXKAD_KEYTAB) && !defined(UKERNEL)
-#include "akimpersonate.h"
-#endif
+#include "authcon.h"
 
 /* return a null security object if nothing else can be done */
 static afs_int32
@@ -52,7 +43,31 @@ QuickAuth(struct rx_securityClass **astr, afs_int32 *aindex)
     return 0;
 }
 
-#if !defined(UKERNEL)
+static int _afsconf_GetRxkadKrb5Key(void *arock, int kvno, int enctype, void *outkey,
+				    size_t *keylen)
+{
+    struct afsconf_dir *adir = arock;
+    struct afsconf_typedKey *kobj;
+    struct rx_opaque *keymat;
+    afsconf_keyType tktype;
+    int tkvno, tenctype;
+    int code;
+
+    code = afsconf_GetKeyByTypes(adir, afsconf_rxkad_krb5, kvno, enctype, &kobj);
+    if (code != 0)
+	return code;
+    afsconf_typedKey_values(kobj, &tktype, &tkvno, &tenctype, &keymat);
+    if (*keylen < keymat->len) {
+	afsconf_typedKey_put(&kobj);
+	return AFSCONF_BADKEY;
+    }
+    memcpy(outkey, keymat->val, keymat->len);
+    *keylen = keymat->len;
+    afsconf_typedKey_put(&kobj);
+    return 0;
+}
+
+
 /* Return an appropriate security class and index */
 afs_int32
 afsconf_ServerAuth(void *arock,
@@ -61,37 +76,14 @@ afsconf_ServerAuth(void *arock,
 {
     struct afsconf_dir *adir = (struct afsconf_dir *) arock;
     struct rx_securityClass *tclass;
-#ifdef USE_RXKAD_KEYTAB
-    int keytab_enable = 0;
-    char *csdb_name;
-    size_t csdblen;
-    char *keytab_name;
-    size_t ktlen;
-    csdblen = strlen(adir->name) + 1 + strlen(AFSDIR_CELLSERVDB_FILE) + 1;
-    csdb_name = malloc(csdblen);
-    ktlen = 5 + strlen(adir->name) + 1 + strlen(AFSDIR_RXKAD_KEYTAB_FILE) + 1;
-    keytab_name = malloc(ktlen);
-    if (csdb_name != NULL && keytab_name != NULL) {
-	strcompose(csdb_name, csdblen, adir->name, "/",
-	           AFSDIR_CELLSERVDB_FILE, (char *)NULL);
-	strcompose(keytab_name, ktlen, "FILE:", adir->name, "/",
-		   AFSDIR_RXKAD_KEYTAB_FILE, (char *)NULL);
-	if (rxkad_InitKeytabDecrypt(csdb_name, keytab_name) == 0)
-	    keytab_enable = 1;
-    }
-    free(csdb_name);
-    free(keytab_name);
-#endif
+
     LOCK_GLOBAL_MUTEX;
     tclass = (struct rx_securityClass *)
-	rxkad_NewServerSecurityObject(0, adir, afsconf_GetKey, NULL);
+	rxkad_NewKrb5ServerSecurityObject(0, adir, afsconf_GetKey,
+					  _afsconf_GetRxkadKrb5Key, NULL);
     if (tclass) {
 	*astr = tclass;
 	*aindex = RX_SECIDX_KAD;
-#ifdef USE_RXKAD_KEYTAB
-	if (keytab_enable)
-	    rxkad_BindKeytabDecrypt(tclass);
-#endif
 	UNLOCK_GLOBAL_MUTEX;
 	return 0;
     } else {
@@ -99,123 +91,78 @@ afsconf_ServerAuth(void *arock,
 	return 2;
     }
 }
-#endif /* !defined(UKERNEL) */
-
-#if defined(USE_RXKAD_KEYTAB) && !defined(UKERNEL)
-static afs_int32
-K5Auth(struct afsconf_dir *adir,
-       struct rx_securityClass **astr,
-       afs_int32 *aindex,
-       rxkad_level enclevel)
-{
-    struct rx_securityClass *tclass;
-    krb5_context context = NULL;
-    krb5_creds* fake_princ = NULL;
-    krb5_principal client_princ = NULL;
-    krb5_error_code r = 0;
-    struct ktc_encryptionKey session;
-    char *keytab_name = NULL;
-    size_t ktlen;
-
-    ktlen = 5 + strlen(adir->name) + 1 + strlen(AFSDIR_RXKAD_KEYTAB_FILE) + 1;
-    keytab_name = malloc(ktlen);
-    if (!keytab_name) {
-	return errno;
-    }
-    strcompose(keytab_name, ktlen, "FILE:", adir->name, "/",
-	       AFSDIR_RXKAD_KEYTAB_FILE, (char *)NULL);
-
-    r = krb5_init_context(&context);
-    if (r)
-	goto cleanup;
-
-    r = krb5_build_principal(context, &client_princ, 1, "\0", "afs", NULL);
-    if (r)
-	goto cleanup;
-
-    r = get_credv5_akimpersonate(context, keytab_name,
-				 NULL, client_princ,
-				 0, 0x7fffffff,
-				 NULL,
-				 &fake_princ);
-
-    if (r == 0) {
-	if (tkt_DeriveDesKey(get_creds_enctype(fake_princ),
-			     get_cred_keydata(fake_princ),
-			     get_cred_keylen(fake_princ),
-			     &session) != 0) {
-	    r = RXKADBADKEY;
-	    goto cleanup;
-	}
-	tclass = (struct rx_securityClass *)
-            rxkad_NewClientSecurityObject(enclevel, &session,
-					  RXKAD_TKT_TYPE_KERBEROS_V5,
-					  fake_princ->ticket.length,
-					  fake_princ->ticket.data);
-	if (tclass != NULL) {
-	    *astr = tclass;
-	    *aindex = RX_SECIDX_KAD;
-	    r = 0;
-	    goto cleanup;
-	}
-	r = 1;
-    }
-
-cleanup:
-    free(keytab_name);
-    if (fake_princ != NULL)
-	krb5_free_creds(context, fake_princ);
-    if (context != NULL)
-	krb5_free_context(context);
-    return r;
-}
-#endif
 
 static afs_int32
 GenericAuth(struct afsconf_dir *adir,
 	    struct rx_securityClass **astr,
 	    afs_int32 *aindex,
-	    rxkad_level enclevel,
-	    int noauth_fallback)
+	    rxkad_level enclevel)
 {
-    char tbuffer[256];
+    int enctype_preflist[]={18, 17, 23, 16, 0};
+    char tbuffer[512];
     struct ktc_encryptionKey key, session;
     struct rx_securityClass *tclass;
     afs_int32 kvno;
     afs_int32 ticketLen;
     afs_int32 code;
-
-#if defined(USE_RXKAD_KEYTAB) && !defined(UKERNEL)
-    /* Try to do things the v5 way, before switching down to v4 */
-    code = K5Auth(adir, astr, aindex, enclevel);
-    if (code == 0)
-	return 0;
-#endif
+    int use_krb5=0;
+    struct afsconf_typedKey *kobj;
+    struct rx_opaque *keymat;
+    int *et;
 
     /* first, find the right key and kvno to use */
-    code = afsconf_GetLatestKey(adir, &kvno, &key);
-    if (code) {
-	goto error;
+
+    et = enctype_preflist;
+    while(*et != 0) {
+	code = afsconf_GetLatestKeyByTypes(adir, afsconf_rxkad_krb5, *et,
+					   &kobj);
+	if (code == 0) {
+	    afsconf_keyType tktype;
+	    int tenctype;
+	    afsconf_typedKey_values(kobj, &tktype, &kvno, &tenctype, &keymat);
+	    RAND_add(keymat->val, keymat->len, 0.0);
+	    use_krb5 = 1;
+	    break;
+	}
+	et++;
     }
 
-    /* next create random session key, using key for seed to good random */
-    des_init_random_number_generator(ktc_to_cblock(&key));
-    code = des_random_key(ktc_to_cblock(&session));
+    if (use_krb5 == 0) {
+	code = afsconf_GetLatestKey(adir, &kvno, &key);
+	if (code) {
+	    return QuickAuth(astr, aindex);
+	}
+	/* next create random session key, using key for seed to good random */
+	DES_init_random_number_generator((DES_cblock *) &key);
+    }
+    code = DES_new_random_key((DES_cblock *) &session);
     if (code) {
-	goto error;
+	if (use_krb5)
+	    afsconf_typedKey_put(&kobj);
+	return QuickAuth(astr, aindex);
     }
 
-    /* now create the actual ticket */
-    ticketLen = sizeof(tbuffer);
-    memset(tbuffer, '\0', sizeof(tbuffer));
-    code =
-	tkt_MakeTicket(tbuffer, &ticketLen, &key, AUTH_SUPERUSER, "", "", 0,
-		       0xffffffff, &session, 0, "afs", "");
-    /* parms were buffer, ticketlen, key to seal ticket with, principal
-     * name, instance and cell, start time, end time, session key to seal
-     * in ticket, inet host, server name and server instance */
+    if (use_krb5) {
+	ticketLen = sizeof(tbuffer);
+	memset(tbuffer, '\0', sizeof(tbuffer));
+	code =
+	    tkt_MakeTicket5(tbuffer, &ticketLen, *et, &kvno, keymat->val,
+			    keymat->len, AUTH_SUPERUSER, "", "", 0, 0x7fffffff,
+			    &session, "afs", "");
+	afsconf_typedKey_put(&kobj);
+    } else {
+	/* now create the actual ticket */
+	ticketLen = sizeof(tbuffer);
+	memset(tbuffer, '\0', sizeof(tbuffer));
+	code =
+	    tkt_MakeTicket(tbuffer, &ticketLen, &key, AUTH_SUPERUSER, "", "", 0,
+			   0xffffffff, &session, 0, "afs", "");
+	/* parms were buffer, ticketlen, key to seal ticket with, principal
+	 * name, instance and cell, start time, end time, session key to seal
+	 * in ticket, inet host, server name and server instance */
+    }
     if (code) {
-	goto error;
+	return QuickAuth(astr, aindex);
     }
 
     /* Next, we have ticket, kvno and session key, authenticate the connection.
@@ -228,12 +175,6 @@ GenericAuth(struct afsconf_dir *adir,
     *astr = tclass;
     *aindex = RX_SECIDX_KAD;
     return 0;
-
- error:
-    if (noauth_fallback) {
-	return QuickAuth(astr, aindex);
-    }
-    return code;
 }
 
 /* build a fake ticket for 'afs' using keys from adir, returning an
@@ -247,7 +188,7 @@ afsconf_ClientAuth(void *arock, struct rx_securityClass ** astr,
     afs_int32 rc;
 
     LOCK_GLOBAL_MUTEX;
-    rc = GenericAuth(adir, astr, aindex, rxkad_clear, 1);
+    rc = GenericAuth(adir, astr, aindex, rxkad_clear);
     UNLOCK_GLOBAL_MUTEX;
     return rc;
 }
@@ -265,7 +206,7 @@ afsconf_ClientAuthSecure(void *arock,
     afs_int32 rc;
 
     LOCK_GLOBAL_MUTEX;
-    rc = GenericAuth(adir, astr, aindex, rxkad_crypt, 1);
+    rc = GenericAuth(adir, astr, aindex, rxkad_crypt);
     UNLOCK_GLOBAL_MUTEX;
     return rc;
 }
@@ -299,7 +240,7 @@ afsconf_ClientAuthToken(struct afsconf_cell *info,
 			afs_int32 *scIndex,
 			time_t *expires)
 {
-    struct ktc_principal sname;
+    struct ktc_setTokenData *tokenSet = NULL;
     struct ktc_token ttoken;
     int encryptLevel;
     afs_int32 code;
@@ -307,11 +248,11 @@ afsconf_ClientAuthToken(struct afsconf_cell *info,
     *sc = NULL;
     *scIndex = RX_SECIDX_NULL;
 
-    strcpy(sname.cell, info->name);
-    sname.instance[0] = 0;
-    strcpy(sname.name, "afs");
-    code = ktc_GetToken(&sname, &ttoken, sizeof(ttoken), NULL);
+    code = ktc_GetTokenEx(info->name, &tokenSet);
+    if (code)
+	goto out;
 
+    code = token_extractRxkad(tokenSet, &ttoken, NULL, NULL);
     if (code == 0) {
 	/* XXX - We should think about how to handle this */
 	if (ttoken.kvno < 0 || ttoken.kvno > 256) {
@@ -332,69 +273,106 @@ afsconf_ClientAuthToken(struct afsconf_cell *info,
 	if (expires)
 	    *expires = ttoken.endTime;
     }
+
+out:
+    token_FreeSet(&tokenSet);
+
     if (*sc == NULL)
 	return AFSCONF_NO_SECURITY_CLASS;
 
     return code;
 }
 
+/*!
+ * Set the security flags to be used for a particular configuration
+ */
+void
+afsconf_SetSecurityFlags(struct afsconf_dir *dir,
+			 afsconf_secflags flags)
+{
+    dir->securityFlags = flags;
+}
+
+static void
+LogDesWarning(struct afsconf_bsso_info *info)
+{
+    if (info->logger == NULL) {
+	return;
+    }
+    /* The blank newlines help this stand out a bit more in the log. */
+    (*info->logger)("\n");
+    (*info->logger)("WARNING: You are using single-DES keys in a KeyFile. Using "
+		    "single-DES\n");
+    (*info->logger)("WARNING: long-term keys is considered insecure, and it is "
+		    "strongly\n");
+    (*info->logger)("WARNING: recommended that you migrate to stronger "
+		    "encryption. See\n");
+    (*info->logger)("WARNING: OPENAFS-SA-2013-003 on "
+		    "http://www.openafs.org/security/\n");
+    (*info->logger)("WARNING: for details.\n");
+    (*info->logger)("\n");
+}
+
+static void
+LogNoKeysWarning(struct afsconf_bsso_info *info)
+{
+    if (info->logger == NULL) {
+	return;
+    }
+    (*info->logger)("WARNING: No encryption keys found! "
+		    "All authenticated accesses will fail. "
+		    "Run akeyconvert or asetkey to import encryption keys.\n");
+}
+
+/* Older version of afsconf_BuildServerSecurityObjects_int. In-tree callers
+ * should use afsconf_BuildServerSecurityObjects_int where possible. */
+void
+afsconf_BuildServerSecurityObjects(void *rock,
+				   struct rx_securityClass ***classes,
+				   afs_int32 *numClasses)
+{
+    struct afsconf_bsso_info info;
+    memset(&info, 0, sizeof(info));
+    info.dir = rock;
+    afsconf_BuildServerSecurityObjects_int(&info, classes, numClasses);
+}
+
 /*!
  * Build a set of security classes suitable for a server accepting
  * incoming connections
  */
-#if !defined(UKERNEL)
 void
-afsconf_BuildServerSecurityObjects(struct afsconf_dir *dir,
-				   afs_uint32 flags,
-			           struct rx_securityClass ***classes,
-			           afs_int32 *numClasses)
+afsconf_BuildServerSecurityObjects_int(struct afsconf_bsso_info *info,
+				       struct rx_securityClass ***classes,
+				       afs_int32 *numClasses)
 {
-#ifdef USE_RXKAD_KEYTAB
-    int keytab_enable = 0;
-    char *csdb_name;
-    size_t csdblen;
-    char *keytab_name;
-    size_t ktlen;
-    csdblen = strlen(dir->name) + 1 + strlen(AFSDIR_CELLSERVDB_FILE) + 1;
-    csdb_name = malloc(csdblen);
-    ktlen = 5 + strlen(dir->name) + 1 + strlen(AFSDIR_RXKAD_KEYTAB_FILE) + 1;
-    keytab_name = malloc(ktlen);
-    if (csdb_name != NULL && keytab_name != NULL) {
-	strcompose(csdb_name, csdblen, dir->name, "/",
-	           AFSDIR_CELLSERVDB_FILE, (char *)NULL);
-	strcompose(keytab_name, ktlen, "FILE:", dir->name, "/",
-		   AFSDIR_RXKAD_KEYTAB_FILE, (char *)NULL);
-	if (rxkad_InitKeytabDecrypt(csdb_name, keytab_name) == 0)
-	    keytab_enable = 1;
+    struct afsconf_dir *dir = info->dir;
+
+    if (afsconf_GetLatestKey(dir, NULL, NULL) == 0) {
+	LogDesWarning(info);
     }
-    free(csdb_name);
-    free(keytab_name);
-#endif
-    if (flags & AFSCONF_SEC_OBJS_RXKAD_CRYPT)
+    if (afsconf_CountKeys(dir) == 0) {
+	LogNoKeysWarning(info);
+    }
+
+    if (dir->securityFlags & AFSCONF_SECOPTS_ALWAYSENCRYPT)
 	*numClasses = 4;
     else
 	*numClasses = 3;
 
     *classes = calloc(*numClasses, sizeof(**classes));
 
-    (*classes)[0] = rxnull_NewServerSecurityObject();
-    (*classes)[1] = NULL;
-    (*classes)[2] = rxkad_NewServerSecurityObject(0, dir,
-						  afsconf_GetKey, NULL);
-#ifdef USE_RXKAD_KEYTAB
-    if (keytab_enable)
-	rxkad_BindKeytabDecrypt((*classes)[2]);
-#endif
-    if (flags & AFSCONF_SEC_OBJS_RXKAD_CRYPT) {
-	(*classes)[3] = rxkad_NewServerSecurityObject(rxkad_crypt, dir,
-						      afsconf_GetKey, NULL);
-#ifdef USE_RXKAD_KEYTAB
-	if (keytab_enable)
-	    rxkad_BindKeytabDecrypt((*classes)[3]);
-#endif
-    }
+    (*classes)[RX_SECIDX_NULL] = rxnull_NewServerSecurityObject();
+    (*classes)[RX_SECIDX_VAB] = NULL;
+    (*classes)[RX_SECIDX_KAD] =
+	rxkad_NewKrb5ServerSecurityObject(0, dir, afsconf_GetKey,
+					  _afsconf_GetRxkadKrb5Key, NULL);
+
+    if (dir->securityFlags & AFSCONF_SECOPTS_ALWAYSENCRYPT)
+	(*classes)[RX_SECIDX_KAE] =
+	    rxkad_NewKrb5ServerSecurityObject(rxkad_crypt, dir, afsconf_GetKey,
+					      _afsconf_GetRxkadKrb5Key, NULL);
 }
-#endif
 
 /*!
  * Pick a security class to use for an outgoing connection
@@ -444,27 +422,33 @@ afsconf_PickClientSecObj(struct afsconf_dir *dir, afsconf_secflags flags,
     *sc = NULL;
     *scIndex = RX_SECIDX_NULL;
     if (expires)
-	expires = 0;
+	*expires = 0;
 
     if ( !(flags & AFSCONF_SECOPTS_NOAUTH) ) {
 	if (!dir)
 	    return AFSCONF_NOCELLDB;
 
 	if (flags & AFSCONF_SECOPTS_LOCALAUTH) {
-	    int fallback = 0;
-	    if (flags & AFSCONF_SECOPTS_FALLBACK_NULL)
-		fallback = 1;
-
-	    LOCK_GLOBAL_MUTEX;
 	    if (flags & AFSCONF_SECOPTS_ALWAYSENCRYPT)
-		code = GenericAuth(dir, sc, scIndex, rxkad_crypt, fallback);
+		code = afsconf_ClientAuthSecure(dir, sc, scIndex);
 	    else
-		code = GenericAuth(dir, sc, scIndex, rxkad_clear, fallback);
-	    UNLOCK_GLOBAL_MUTEX;
+		code = afsconf_ClientAuth(dir, sc, scIndex);
 
 	    if (code)
 		goto out;
 
+	    /* The afsconf_ClientAuth functions will fall back to giving
+	     * a rxnull object, which we don't want if localauth has been
+	     * explicitly requested. Check for this, and bail out if we
+	     * get one. Note that this leaks a security object at present
+	     */
+	    if (!(flags & AFSCONF_SECOPTS_FALLBACK_NULL) &&
+		*scIndex == RX_SECIDX_NULL) {
+		sc = NULL;
+		code = AFSCONF_NOTFOUND;
+		goto out;
+	    }
+
 	    if (expires)
 		*expires = NEVERDATE;
 	} else {
