@@ -7,10 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
+#include <afsconfig.h>
+#include <afs/param.h>
+
+#include <roken.h>
+
 #include <lwp.h>
 #include <rx/rx.h>
 #include <afs/bubasics.h>
@@ -18,9 +19,8 @@
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     int argc;
-     char **argv;
+int
+main(int argc, char **argv)
 {
     struct rx_securityClass *rxsc;
     struct rx_connection *tconn;
