@@ -32,9 +32,6 @@
 
 #define	AFS_SYSCALL		65
 
-/* File system entry (used if mount.h doesn't define MOUNT_AFS */
-#define AFS_MOUNT_AFS	 "afs"
-
 /* Machine / Operating system information */
 #define sys_sun4x_59	1
 #define SYS_NAME	"sun4x_59"
@@ -124,8 +121,7 @@
 #define	AFS_3DISPARES		1	/* Utilize the 3 available disk inode 'spares' */
 #define	AFS_SYSCALL		65
 
-/* File system entry (used if mount.h doesn't define MOUNT_AFS */
-#define AFS_MOUNT_AFS	 1
+#define AFS_FSNO	 1
 
 /* Machine / Operating system information */
 #define sys_sun4x_59	1
