@@ -72,11 +72,9 @@ extern int DNew(struct dcache *adc, int page, struct DirBuffer *);
 # include "dir.h"
 #endif /* KERNEL */
 
-afs_int32 DErrno;
-
 /* Local static prototypes */
 static int FindBlobs(dir_file_t, int);
-static void AddPage(dir_file_t, int);
+static int AddPage(dir_file_t, int);
 static void FreeBlobs(dir_file_t, int, int);
 static int FindItem(dir_file_t, char *, struct DirBuffer *,
 		    struct DirBuffer *);
@@ -99,7 +97,7 @@ afs_dir_Create(dir_file_t dir, char *entry, void *voidfid)
     int blobs, firstelt;
     int i;
     struct DirBuffer entrybuf, prevbuf, headerbuf;
-    struct DirEntry *ep;
+    struct DirEntryFlex *ep;
     struct DirHeader *dhp;
     int code;
     size_t rlen;
@@ -127,7 +125,7 @@ afs_dir_Create(dir_file_t dir, char *entry, void *voidfid)
     /* First, we fill in the directory entry. */
     if (afs_dir_GetBlob(dir, firstelt, &entrybuf) != 0)
 	return EIO;
-    ep = (struct DirEntry *)entrybuf.data;
+    ep = entrybuf.data;
 
     ep->flag = FFIRST;
     ep->fid.vnode = htonl(vfid[1]);
@@ -213,7 +211,15 @@ afs_dir_Delete(dir_file_t dir, char *entry)
     return 0;
 }
 
-/* Find a bunch of contiguous entries; at least nblobs in a row. */
+/*!
+ * Find a bunch of contiguous entries; at least nblobs in a row.
+ *
+ * \param dir	    pointer to the directory object
+ * \param nblobs    number of contiguous entries we need
+ *
+ * \return element number (directory entry) of the requested space
+ * \retval -1		failed to find 'nblobs' contiguous entries
+ */
 static int
 FindBlobs(dir_file_t dir, int nblobs)
 {
@@ -223,6 +229,7 @@ FindBlobs(dir_file_t dir, int nblobs)
     struct DirHeader *dhp;
     struct PageHeader *pp;
     int pgcount;
+    int code;
 
     /* read the dir header in first. */
     if (DRead(dir, 0, &headerbuf) != 0)
@@ -242,12 +249,16 @@ FindBlobs(dir_file_t dir, int nblobs)
 		}
 		if (i > pgcount - 1) {
 		    /* this page is bigger than last allocated page */
-		    AddPage(dir, i);
+		    code = AddPage(dir, i);
+		    if (code)
+			break;
 		    dhp->header.pgcount = htons(i + 1);
 		}
 	    } else if (dhp->alloMap[i] == EPP) {
 		/* Add the page to the directory. */
-		AddPage(dir, i);
+		code = AddPage(dir, i);
+		if (code)
+		    break;
 		dhp->alloMap[i] = EPP - 1;
 		dhp->header.pgcount = htons(i + 1);
 	    }
@@ -282,20 +293,32 @@ FindBlobs(dir_file_t dir, int nblobs)
 	    DRelease(&pagebuf, 0);	/* This dir page is unchanged. */
 	}
     }
-    /* If we make it here, the directory is full. */
+    /* If we make it here, the directory is full, or we encountered an I/O error. */
     DRelease(&headerbuf, 1);
     return -1;
 }
 
-static void
+/*!
+ * Add a page to a directory object.
+ *
+ * \param dir	    pointer to the directory object
+ * \param pageno    page number to add
+ *
+ * \retval 0	    succcess
+ * \retval non-zero return error from DNew
+ */
+static int
 AddPage(dir_file_t dir, int pageno)
 {				/* Add a page to a directory. */
     int i;
     struct PageHeader *pp;
     struct DirBuffer pagebuf;
+    int code;
 
     /* Get a new buffer labelled dir,pageno */
-    DNew(dir, pageno, &pagebuf);
+    code = DNew(dir, pageno, &pagebuf);
+    if (code)
+	return code;
     pp = (struct PageHeader *)pagebuf.data;
 
     pp->tag = htons(1234);
@@ -306,6 +329,7 @@ AddPage(dir_file_t dir, int pageno)
     for (i = 1; i < EPP / 8; i++)	/* It's a constant */
 	pp->freebitmap[i] = 0;
     DRelease(&pagebuf, 1);
+    return 0;
 }
 
 /* Free a whole bunch of directory entries. */
@@ -340,10 +364,17 @@ FreeBlobs(dir_file_t dir, int firstblob, int nblobs)
     DRelease(&pagehdbuf, 1);
 }
 
-/*
+/*!
  * Format an empty directory properly.  Note that the first 13 entries in a
  * directory header page are allocated, 1 to the page header, 4 to the
  * allocation map and 8 to the hash table.
+ *
+ * \param dir	    pointer to the directory object
+ * \param me	    fid (vnode+uniq) for new dir
+ * \param parent    fid (vnode+uniq) for parent dir
+ *
+ * \retval 0	    success
+ * \retval nonzero  error code
  */
 int
 afs_dir_MakeDir(dir_file_t dir, afs_int32 * me, afs_int32 * parent)
@@ -351,8 +382,11 @@ afs_dir_MakeDir(dir_file_t dir, afs_int32 * me, afs_int32 * parent)
     int i;
     struct DirBuffer buffer;
     struct DirHeader *dhp;
+    int code;
 
-    DNew(dir, 0, &buffer);
+    code = DNew(dir, 0, &buffer);
+    if (code)
+	return code;
     dhp = (struct DirHeader *)buffer.data;
 
     dhp->header.pgcount = htons(1);
@@ -368,8 +402,12 @@ afs_dir_MakeDir(dir_file_t dir, afs_int32 * me, afs_int32 * parent)
     for (i = 0; i < NHASHENT; i++)
 	dhp->hashTable[i] = 0;
     DRelease(&buffer, 1);
-    afs_dir_Create(dir, ".", me);
-    afs_dir_Create(dir, "..", parent);	/* Virtue is its own .. */
+    code = afs_dir_Create(dir, ".", me);
+    if (code)
+	return code;
+    code = afs_dir_Create(dir, "..", parent);
+    if (code)
+	return code;
     return 0;
 }
 
@@ -518,11 +556,14 @@ afs_dir_IsEmpty(dir_file_t dir)
 /* Return a pointer to an entry, given its number. Also return the maximum
  * size of the entry, which is determined by its position within the directory
  * page.
+ *
+ * If physerr is supplied by caller, it will be set to:
+ *      0       for logical errors
+ *      errno   for physical errors
  */
-
 static int
 GetBlobWithLimit(dir_file_t dir, afs_int32 blobno,
-	         struct DirBuffer *buffer, afs_size_t *maxlen)
+		struct DirBuffer *buffer, afs_size_t *maxlen, int *physerr)
 {
     afs_size_t pos;
     int code;
@@ -530,7 +571,7 @@ GetBlobWithLimit(dir_file_t dir, afs_int32 blobno,
     *maxlen = 0;
     memset(buffer, 0, sizeof(struct DirBuffer));
 
-    code = DRead(dir, blobno >> LEPP, buffer);
+    code = DReadWithErrno(dir, blobno >> LEPP, buffer, physerr);
     if (code)
 	return code;
 
@@ -543,12 +584,26 @@ GetBlobWithLimit(dir_file_t dir, afs_int32 blobno,
     return 0;
 }
 
+/*
+ * Given an entry's number, return a pointer to that entry.
+ * If physerr is supplied by caller, it will be set to:
+ *      0       for logical errors
+ *      errno   for physical errors
+ */
+int
+afs_dir_GetBlobWithErrno(dir_file_t dir, afs_int32 blobno, struct DirBuffer *buffer,
+			int *physerr)
+{
+    afs_size_t maxlen = 0;
+    return GetBlobWithLimit(dir, blobno, buffer, &maxlen, physerr);
+}
+
 /* Given an entries number, return a pointer to that entry */
 int
 afs_dir_GetBlob(dir_file_t dir, afs_int32 blobno, struct DirBuffer *buffer)
 {
     afs_size_t maxlen = 0;
-    return GetBlobWithLimit(dir, blobno, buffer, &maxlen);
+    return GetBlobWithLimit(dir, blobno, buffer, &maxlen, NULL);
 }
 
 /* Return an entry, having verified that the name held within the entry
@@ -566,7 +621,7 @@ afs_dir_GetVerifiedBlob(dir_file_t file, afs_int32 blobno,
     int code;
     char *cp;
 
-    code = GetBlobWithLimit(file, blobno, &buffer, &maxlen);
+    code = GetBlobWithLimit(file, blobno, &buffer, &maxlen, NULL);
     if (code)
 	return code;
 
