@@ -232,7 +232,7 @@ get_syms(conf, syms)
     if (debug)
 	printf("nsyms = %d\n", nsyms);
 
-    x_symtab = (struct syment *)malloc(nsyms * SYMESZ);
+    x_symtab = malloc(nsyms * SYMESZ);
     if (!x_symtab)
 	error("no memory for symbol table");
 
@@ -326,7 +326,7 @@ get_syms(conf, syms)
     /*
      * we will need no more than `nxsyms' symbols.
      */
-    k_symtab = (sym_t *) malloc(nxsyms * sizeof(sym_t));
+    k_symtab = malloc(nxsyms * sizeof(sym_t));
     if (!k_symtab)
 	error("no memory for EXPORT symbol table");
 
@@ -420,16 +420,6 @@ xlate_xtok(xp, kp, strp, szp)
 	while (len >= left) {
 	    fprintf(stderr, "cfgexport: Out of memory. Increase SYMBUFSIZE and recompile\n");
 	    exit(1);
-#if 0
-	    /* Something is broken with this code, after being here
-	       cfgexport segfaults */
-	    export_strings = (char *)realloc(*strp, sz += SYMBUFSIZE);
-	    if (!export_strings)
-		error("no memory for EXPORT string table");
-	    *strp = export_strings;
-	    left += SYMBUFSIZE;
-	    prev = "";		/* lazy */
-#endif
 	}
 
 	strcpy(prev = *strp + offset, xstrings + xp->n_offset);
@@ -459,7 +449,7 @@ xlate_xtok(xp, kp, strp, szp)
 	 */
 	len = strlen(xp->n_nptr) + 1;
 	while (len >= left) {
-	    export_strings = (char *)realloc(*strp, sz += SYMBUFSIZE);
+	    export_strings = realloc(*strp, sz += SYMBUFSIZE);
 	    if (!export_strings)
 		error("no memory for EXPORT string table");
 	    *strp = export_strings;
