@@ -10,33 +10,23 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-
 #ifdef	KERNEL
-#include <afs/sysincludes.h>
-#include <afsincludes.h>
+# include <afs/sysincludes.h>
+# include <afsincludes.h>
 #else
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#include <malloc.h>
-#else
-#include <sys/param.h>
-#endif
-#include <errno.h>
-#include <afs/errors.h>
-#include "xdr.h"
-#ifdef AFS_PTHREAD_ENV
-#include "rx.h"
-#endif /* AFS_PTHREAD_ENV */
-#include <stdlib.h>
-#include <string.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#ifdef AFS_NT40_ENV
-#ifndef EDQUOT
-#define EDQUOT WSAEDQUOT
-#endif /* EDQUOT */
-#endif /* AFS_NT40_ENV */
+# include <roken.h>
+# include <afs/opr.h>
+
+# include <afs/errors.h>
+# include "xdr.h"
+# ifdef AFS_PTHREAD_ENV
+#  include "rx.h"
+# endif /* AFS_PTHREAD_ENV */
+# ifdef AFS_NT40_ENV
+#  ifndef EDQUOT
+#   define EDQUOT WSAEDQUOT
+#  endif /* EDQUOT */
+# endif /* AFS_NT40_ENV */
 #endif
 
 /*
@@ -96,21 +86,6 @@ ntoh_syserr_conv(int code)
  */
 
 #ifndef osi_alloc
-#ifdef AFS_PTHREAD_ENV
-/*
- * This mutex protects the following global variables:
- * osi_alloccnt
- * osi_allocsize
- */
-
-afs_kmutex_t osi_malloc_mutex;
-#define LOCK_MALLOC_STATS MUTEX_ENTER(&osi_malloc_mutex);
-#define UNLOCK_MALLOC_STATS MUTEX_EXIT(&osi_malloc_mutex);
-#else
-#define LOCK_MALLOC_STATS
-#define UNLOCK_MALLOC_STATS
-#endif /* AFS_PTHREAD_ENV */
-long osi_alloccnt = 0, osi_allocsize = 0;
 static const char memZero;
 char *
 osi_alloc(afs_int32 x)
@@ -121,10 +96,6 @@ osi_alloc(afs_int32 x)
      */
     if (x == 0)
 	return (char *)&memZero;
-    LOCK_MALLOC_STATS;
-    osi_alloccnt++;
-    osi_allocsize += x;
-    UNLOCK_MALLOC_STATS;
     return (char *)(mem_alloc(x));
 }
 
@@ -133,10 +104,6 @@ osi_free(char *x, afs_int32 size)
 {
     if ((x == &memZero) || !x)
 	return 0;
-    LOCK_MALLOC_STATS;
-    osi_alloccnt--;
-    osi_allocsize -= size;
-    UNLOCK_MALLOC_STATS;
     mem_free(x, size);
     return 0;
 }
@@ -154,7 +121,7 @@ int rx_callHoldType = 0;
  * RX_LOCKS_DB versions of MUTEX_{ENTER, EXIT, TRYENTER} and CV_*WAIT to
  * rx_kmutex.h and define lock macros below.
  */
-#if (defined(AFS_AIX41_ENV) || (defined(AFS_SGI53_ENV) && defined(MP))) && defined(KERNEL)
+#if (defined(AFS_AIX41_ENV) || (defined(AFS_SGI_ENV) && defined(MP))) && defined(KERNEL)
 
 #ifdef AFS_AIX41_ENV
 Simple_lock rxdb_lock;
@@ -163,12 +130,12 @@ Simple_lock rxdb_lock;
 #define RXDB_LOCK_ENTER()	simple_lock(&rxdb_lock)
 #define RXDB_LOCK_EXIT()	simple_unlock(&rxdb_lock)
 #else /* AFS_AIX41_ENV */
-#ifdef AFS_SGI53_ENV
+#ifdef AFS_SGI_ENV
 afs_kmutex_t rxdb_lock;
 #define RXDB_LOCK_INIT()	mutex_init(&rxdb_lock, "rxdb lock", 0, 0)
 #define RXDB_LOCK_ENTER()	AFS_MUTEX_ENTER(&rxdb_lock)
 #define RXDB_LOCK_EXIT()	mutex_exit(&rxdb_lock)
-#endif /* AFS_SGI53_ENV */
+#endif /* AFS_SGI_ENV */
 #endif /* AFS_AIX41_ENV */
 
 
@@ -383,6 +350,6 @@ rxdb_droplock(a, id, fileId, line)
     RXDB_LOCK_EXIT();
 }
 
-#endif /* (AIX41 || SGI53) && KERNEL */
+#endif /* (AIX41 || SGI) && KERNEL */
 
 #endif /* RX_LOCKS_DB */
