@@ -133,12 +133,7 @@ rxi_StartServerProc(void *(*proc) (void *), int stacksize)
 static void *
 event_handler(void *argp)
 {
-    unsigned long rx_pthread_n_event_expired = 0;
-    unsigned long rx_pthread_n_event_waits = 0;
-    long rx_pthread_n_event_woken = 0;
-    unsigned long rx_pthread_n_event_error = 0;
     struct timespec rx_pthread_next_event_time = { 0, 0 };
-    int error;
 
     MUTEX_ENTER(&event_handler_mutex);
 
@@ -162,24 +157,7 @@ event_handler(void *argp)
 	clock_Add(&cv, &next);
 	rx_pthread_next_event_time.tv_sec = cv.sec;
 	rx_pthread_next_event_time.tv_nsec = cv.usec * 1000;
-	rx_pthread_n_event_waits++;
-	error = CV_TIMEDWAIT(&rx_event_handler_cond, &event_handler_mutex, &rx_pthread_next_event_time);
-        if (error == 0) {
-	    rx_pthread_n_event_woken++;
-        }
-#ifdef AFS_NT40_ENV
-        else if (error == ETIMEDOUT) {
-	    rx_pthread_n_event_expired++;
-	} else {
-            rx_pthread_n_event_error++;
-        }
-#else
-        else if (errno == ETIMEDOUT) {
-            rx_pthread_n_event_expired++;
-        } else {
-            rx_pthread_n_event_error++;
-        }
-#endif
+	CV_TIMEDWAIT(&rx_event_handler_cond, &event_handler_mutex, &rx_pthread_next_event_time);
 	rx_pthread_event_rescheduled = 0;
     }
     AFS_UNREACHED(return(NULL));
