@@ -10,23 +10,8 @@
 #ifndef _RX_XMIT_NT_H_
 #define _RX_XMIT_NT_H_
 
-typedef struct iovec
-{
-    unsigned long iov_len;
-    char *iov_base;
-}
-iovec_t;
-
-struct msghdr {
-    char *msg_name;
-    int msg_namelen;
-    iovec_t *msg_iov;
-    int msg_iovlen;
-    caddr_t msg_accrights;
-    int msg_accrightslen;
-};
-
 extern int rxi_sendmsg(osi_socket socket, struct msghdr *msgP, int flags);
+#undef sendmsg
 #define sendmsg rxi_sendmsg
 extern int rxi_recvmsg(osi_socket socket, struct msghdr *msgP, int flags);
 #define recvmsg rxi_recvmsg
