@@ -164,29 +164,7 @@ do_rx_Init(void)
 struct rx_securityClass *
 get_sc(char *cellname)
 {
-#if 0
-    char realm[REALM_SZ];
-    CREDENTIALS c;
-#endif
-
     return rxnull_NewClientSecurityObject();
-#if 0
-
-    ucstring(realm, cellname, REALM_SZ);
-
-    if (krb_get_cred("afs", "", realm, &c)) {
-	if (get_ad_tkt("afs", "", realm, DEFAULT_TKT_LIFE)) {
-	    return NULL;
-	} else {
-	    if (krb_get_cred("afs", "", realm, &c)) {
-		return NULL;
-	    }
-	}
-    }
-
-    return rxkad_NewClientSecurityObject(rxkad_clear, c.session, c.kvno,
-					 c.ticket_st.length, c.ticket_st.dat);
-#endif
 }
 
 #define scindex_NULL 0
@@ -210,7 +188,6 @@ main(int argc, char **argv)
     int filesz = 0;
     int ch, blksize, bytesremaining, bytes;
     struct timeval start, finish;
-    struct timezone tz;
     struct rx_securityClass *ssc = 0, *dsc = 0;
     int sscindex, dscindex;
     struct rx_connection *sconn = NULL, *dconn = NULL;
@@ -433,7 +410,7 @@ main(int argc, char **argv)
 	scall = rx_NewCall(sconn);
     if (!dlcl && !unlock)
 	dcall = rx_NewCall(dconn);
-    gettimeofday(&start, &tz);
+    gettimeofday(&start, NULL);
     if (unlock) {
 	if (fst.lockCount) {
 	    printf("Sending 1 unlock for %s (%d locks)\n", srcf, fst.lockCount);
@@ -553,7 +530,7 @@ main(int argc, char **argv)
     if (storecode)
 	printf("Error returned from store: %s\n", afs_error_message(storecode));
 Finish:
-    gettimeofday(&finish, &tz);
+    gettimeofday(&finish, NULL);
 
     if (!slcl) {
 	theFids.AFSCBFids_len = 1;
