@@ -57,6 +57,7 @@
 #include <afs/vnode.h>
 #include <afs/volume.h>
 #include <afs/auth.h>
+#include <afs/authcon.h>
 #include <afs/cellconfig.h>
 #include <afs/acl.h>
 #include <afs/prs_fs.h>
@@ -1844,6 +1845,7 @@ main(int argc, char *argv[])
     struct tm tm;
     afs_uint32 rx_bindhost;
     VolumePackageOptions opts;
+    struct afsconf_bsso_info bsso;
 
 #ifdef	AFS_AIX32_ENV
     struct sigaction nsa;
@@ -1856,6 +1858,8 @@ main(int argc, char *argv[])
 #endif
     osi_audit_init();
 
+    memset(&bsso, 0, sizeof(bsso));
+
     /* Initialize dirpaths */
     if (!(initAFSDirPath() & AFSDIR_SERVER_PATHS_OK)) {
 #ifdef AFS_NT40_ENV
@@ -1901,14 +1905,6 @@ main(int argc, char *argv[])
 
     LogCommandLine(argc, argv, "starting", "", "File server", FSLog);
 
-    if (afsconf_CountKeys(confDir) == 0) {
-	ViceLog(0, ("WARNING: No encryption keys found! "
-		    "All authenticated accesses will fail. "
-		    "Run akeyconvert or asetkey to import encryption keys.\n"));
-    } else if (afsconf_GetLatestKey(confDir, NULL, NULL) == 0) {
-	LogDesWarning();
-    }
-
     /* initialize the pthread soft signal handler thread */
     opr_softsig_Init();
     SetupLogSoftSignals();
@@ -2008,7 +2004,7 @@ main(int argc, char *argv[])
     else if (stackSize > 44000)
 	stackSize = 44000;
 #endif
-#if defined(AFS_HPUX_ENV) || defined(AFS_SUN_ENV) || defined(AFS_SGI51_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_HPUX_ENV) || defined(AFS_SUN_ENV) || defined(AFS_SGI_ENV) || defined(AFS_XBSD_ENV)
     rx_SetStackSize(1, stackSize);
 #endif
     if (udpBufSize)
@@ -2032,7 +2028,11 @@ main(int argc, char *argv[])
     rx_GetIFInfo();
     rx_SetRxDeadTime(30);
     afsconf_SetSecurityFlags(confDir, AFSCONF_SECOPTS_ALWAYSENCRYPT);
-    afsconf_BuildServerSecurityObjects(confDir, &securityClasses, &numClasses);
+
+    bsso.dir = confDir;
+    bsso.logger = FSLog;
+    afsconf_BuildServerSecurityObjects_int(&bsso, &securityClasses,
+					   &numClasses);
 
     tservice = rx_NewServiceHost(rx_bindhost,  /* port */ 0, /* service id */
 				 1,	/*service name */
@@ -2045,8 +2045,12 @@ main(int argc, char *argv[])
 	exit(-1);
     }
     if (rxkadDisableDotCheck) {
-        rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
-                                    (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	code = rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
+					   (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	if (code) {
+	    ViceLog(0, ("Failed to allow dotted principals: code %d\n", code));
+	    exit(-1);
+	}
     }
     rx_SetMinProcs(tservice, 3);
     rx_SetMaxProcs(tservice, lwps);
