@@ -41,6 +41,7 @@
 #include <rx/rxstat.h>
 #include <rx/rx_globals.h>
 #include <afs/auth.h>
+#include <afs/authcon.h>
 #include <afs/cellconfig.h>
 #include <afs/keys.h>
 #include <afs/dir.h>
@@ -444,6 +445,7 @@ main(int argc, char **argv)
     int rxpackets = 100;
     afs_uint32 host = ntohl(INADDR_ANY);
     VolumePackageOptions opts;
+    struct afsconf_bsso_info bsso;
 
 #ifdef	AFS_AIX32_ENV
     /*
@@ -463,6 +465,8 @@ main(int argc, char **argv)
     osi_audit_init();
     osi_audit(VS_StartEvent, 0, AUD_END);
 
+    memset(&bsso, 0, sizeof(bsso));
+
     /* Initialize dirpaths */
     if (!(initAFSDirPath() & AFSDIR_SERVER_PATHS_OK)) {
 #ifdef AFS_NT40_ENV
@@ -593,7 +597,9 @@ main(int argc, char **argv)
     /* initialize audit user check */
     osi_audit_set_user_check(tdir, vol_IsLocalRealmMatch);
 
-    afsconf_BuildServerSecurityObjects(tdir, &securityClasses, &numClasses);
+    bsso.dir = tdir;
+    bsso.logger = FSLog;
+    afsconf_BuildServerSecurityObjects_int(&bsso, &securityClasses, &numClasses);
     if (securityClasses[0] == NULL)
 	Abort("rxnull_NewServerSecurityObject");
     service =
@@ -616,8 +622,14 @@ main(int argc, char **argv)
 #endif
 
     if (rxkadDisableDotCheck) {
-        rx_SetSecurityConfiguration(service, RXS_CONFIG_FLAGS,
-                                    (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	code = rx_SetSecurityConfiguration(service, RXS_CONFIG_FLAGS,
+					   (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	if (code) {
+	    fprintf(stderr,
+		    "volser: failed to allow dotted principals: code %d\n",
+		    code);
+	    VS_EXIT(1);
+	}
     }
 
     service =
@@ -630,13 +642,6 @@ main(int argc, char **argv)
 
     LogCommandLine(argc, argv, "Volserver", VolserVersion, "Starting AFS",
 		   Log);
-    if (afsconf_CountKeys(tdir) == 0) {
-	Log("WARNING: No encryption keys found! "
-	    "All authenticated accesses will fail. "
-	    "Run akeyconvert or asetkey to import encryption keys.\n");
-    } else if (afsconf_GetLatestKey(tdir, NULL, NULL) == 0) {
-	LogDesWarning();
-    }
 
     /* allow super users to manage RX statistics */
     rx_SetRxStatUserOk(vol_rxstat_userok);
